/// Help content for PrayerTracker
module PrayerTracker.Views.Help

open System.IO
open Giraffe.ViewEngine
open PrayerTracker.ViewModels

/// The help index page
let index () =
    let s   = I18N.localizer.Force()
    let l   = I18N.forView "Help/Index"
    use sw  = new StringWriter()
    let raw = rawLocText sw
    [ p [] [
          raw l["Throughout PrayerTracker, you'll see an icon (a question mark in a circle) next to the title on each page."]; space
          raw l["Clicking this will open a new, small window with directions on using that page."]; space
          raw l["If you are looking for a quick overview of PrayerTracker, start with the “Add / Edit a Request” and “Change Preferences” entries."] ]
      hr []
      p [ _class "pt-center-text" ] [ strong [] [ locStr s["Help Topics"] ] ]
      p [] [ a [ _href "/help/small-group/preferences"  ] [ locStr s["Change Preferences"]     ] ]
      p [] [ a [ _href "/help/small-group/announcement" ] [ locStr s["Send Announcement"]      ] ]
      p [] [ a [ _href "/help/small-group/members"      ] [ locStr s["Maintain Group Members"] ] ]
      p [] [ a [ _href "/help/requests/edit"            ] [ locStr s["Add / Edit a Request"]   ] ]
      p [] [ a [ _href "/help/requests/maintain"        ] [ locStr s["Maintain Requests"]      ] ]
      p [] [ a [ _href "/help/requests/view"            ] [ locStr s["View Request List"]      ] ]
      p [] [ a [ _href "/help/user/log-on"              ] [ locStr s["Log On"]                 ] ]
      p [] [ a [ _href "/help/user/password"            ] [ locStr s["Change Your Password"]   ] ] ]


/// Help for prayer requests
module Requests =
    
    /// Add / Edit a Request
    let edit () =
        let s   = I18N.localizer.Force()
        let l   = I18N.forView "Help/Requests/Edit"
        use sw  = new StringWriter()
        let raw = rawLocText sw
        [ p [] [ raw l["This page allows you to enter or update a new prayer request."] ]
          h2 [ _id "request-type" ] [ locStr s["Request Type"] ]
          p [] [
              raw l["There are 5 request types in PrayerTracker."]; space
              raw l["“Current Requests” are your regular requests that people may have regarding things happening over the next week or so."]; space
              raw l["“Long-Term Requests” are requests that may occur repeatedly or continue indefinitely."]; space
              raw l["“Praise Reports” are like “Current Requests”, but they are answers to prayer to share with your group."]; space
              raw l["“Expecting” is for those who are pregnant."]; space
              raw l["“Announcements” are like “Current Requests”, but instead of a request, they are simply passing information along about something coming up."] ]
          p [] [
              raw l["The order above is the order in which the request types appear on the list."]; space
              raw l["“Long-Term Requests” and “Expecting” are not subject to the automatic expiration (set on the “Change Preferences” page) that the other requests are."] ]
          h2 [ _id "date" ] [ locStr s["Date"] ]
          p [] [
              raw l["For new requests, this is a box with a calendar date picker."]; space
              raw l["Click or tab into the box to display the calendar, which will be preselected to today's date."]; space
              raw l["For existing requests, there will be a check box labeled “Check to not update the date”."]; space
              raw l["This can be used if you are correcting spelling or punctuation, and do not have an actual update to make to the request."]
          ]
          h2 [ _id "requestor-subject" ] [ locStr s["Requestor / Subject"] ]
          p [] [
              raw l["For requests or praises, this field is for the name of the person who made the request or offered the praise report."]; space
              raw l["For announcements, this should contain the subject of the announcement."]; space
              raw l["For all types, it is optional; I used to have an announcement with no subject that ran every week, telling where to send requests and updates."] ]
          h2 [ _id "expiration" ] [ locStr s["Expiration"] ]
          p [] [
              raw l["“Expire Normally” means that the request is subject to the expiration days in the group preferences."]; space
              raw l["“Request Never Expires” can be used to make a request never expire (note that this is redundant for “Long-Term Requests” and “Expecting”)."]; space
              raw l["If you are editing an existing request, a third option appears."]; space
              raw l["“Expire Immediately” will make the request expire when it is saved."]; space
              raw l["Apart from the icons on the request maintenance page, this is the only way to expire “Long-Term Requests” and “Expecting” requests, but it can be used for any request type."] ]
          h2 [ _id "request" ] [ locStr s["Request"] ]
          p [] [
              raw l["This is the text of the request."]; space
              raw l["The editor provides many formatting capabilities, including “Spell Check as you Type” (enabled by default), “Paste from Word”, and “Paste Plain”, as well as “Source” view, if you want to edit the HTML yourself."]; space
              raw l["It also supports undo and redo, and the editor supports full-screen mode. Hover over each icon to see what each button does."] ] ]
    
    /// Maintain Requests
    let maintain () =
        let s   = I18N.localizer.Force()
        let l   = I18N.forView "Help/Requests/Maintain"
        use sw  = new StringWriter()
        let raw = rawLocText sw
        [ p [] [
              raw l["From this page, you can add, edit, and delete your current requests."]; space
              raw l["You can also restore requests that may have expired, but should be made active once again."] ]
          h2 [ _id "add-a-new-request" ] [ locStr s["Add a New Request"] ]
          p [] [
              raw l["To add a request, click the icon or text in the center of the page, below the title and above the list of requests for your group."] ]
          h2 [ _id "search-requests" ] [ locStr s["Search Requests"] ]
          p [] [
              raw l["If you are looking for a particular requests, enter some text in the search box and click “Search”."]; space
              raw l["PrayerTracker will search the Requestor/Subject and Request Text fields (case-insensitively) of both active and inactive requests."]; space
              raw l["The results will be displayed in the same format as the original Maintain Requests page, so the buttons described below will work the same for those requests as well."]; space
              raw l["They will also be displayed in pages, if there are a lot of results; the number per page is configurable by small group."] ]
          h2 [ _id "edit-request" ] [ locStr s["Edit Request"] ]
          p [] [
              raw l["To edit a request, click the pencil icon; it's the first icon under the “Actions” column heading."] ]
          h2 [ _id "expire-a-request" ] [ locStr s["Expire a Request"] ]
          p [] [
              raw l["For active requests, the second icon is an eye with a slash through it; clicking this icon will expire the request immediately."]; space
              raw l["This is equivalent to editing the request, selecting “Expire Immediately”, and saving it."] ]
          h2 [ _id "restore-an-inactive-request" ] [ locStr s["Restore an Inactive Request"] ]
          p [] [
              raw l["When the page is first displayed, it does not display inactive requests."]; space
              raw l["However, clicking the link at the bottom of the page will refresh the page with the inactive requests shown."]; space
              raw l["The middle icon will look like an eye; clicking it will restore the request as an active request."]; space
              raw l["The last updated date will be current, and the request is set to expire normally."] ]
          h2 [ _id "delete-a-request" ] [ locStr s["Delete a Request"] ]
          p [] [
              raw l["Deleting a request is contrary to the intent of PrayerTracker, as you can retrieve requests that have expired."]; space
              raw l["However, if there is a request that needs to be deleted, clicking the trash can icon in the “Actions” column will allow you to do it."]; space
              raw l["Use this option carefully, as these deletions cannot be undone; once a request is deleted, it is gone for good."] ] ]
    
    /// View Request List
    let view () =
        let s   = I18N.localizer.Force()
        let l   = I18N.forView "Help/Requests/View"
        use sw  = new StringWriter()
        let raw = rawLocText sw
        [ p [] [
              raw l["From this page, you can view the request list (for today or for the next Sunday), view a printable version of the list, and e-mail the list to the members of your group."]; space
              raw l["(NOTE: If you are logged in as a group member, the only option you will see is to view a printable list.)"] ]
          h2 [ _id "list-for-next-sunday" ] [ locStr s["List for Next Sunday"] ]
          p [] [
              raw l["This will modify the date for the list, so it will look like it is currently next Sunday."]; space
              raw l["This can be used, for example, to see what requests will expire, or allow you to print a list with Sunday's date on Saturday evening."]; space
              raw l["Note that this link does not appear if it is Sunday."] ]
          h2 [ _id "view-printable" ] [ locStr s["View Printable"] ]
          p [] [
              raw l["Clicking this link will display the list in a format that is suitable for printing; it does not have the normal PrayerTracker header across the top."]; space
              raw l["Once you have clicked the link, you can print it using your browser's standard “Print” functionality."] ]
          h2 [ _id "send-via-e-mail" ] [ locStr s["Send via E-mail"] ]
          p [] [
              raw l["Clicking this link will send the list you are currently viewing to your group members."]; space
              raw l["The page will remind you that you are about to do that, and ask for your confirmation."]; space
              raw l["If you proceed, you will see a page that shows to whom the list was sent, and what the list looked like."]; space
              raw l["You may safely use your browser's “Back” button to navigate away from the page."] ] ]


/// Help for small group pages
module SmallGroup =
    
    /// Send an Announcement
    let announcement () =
        let s   = I18N.localizer.Force()
        let l   = I18N.forView "Help/SmallGroup/Announcement"
        use sw  = new StringWriter()
        let raw = rawLocText sw
        [ h2 [ _id "announcement-text" ] [ locStr s["Announcement Text"] ]
          p [] [
              raw l["This is the text of the announcement you would like to send."]; space
              raw l["""It functions the same way as the text box on the <a href="../requests/edit#request">“Edit Request” page</a>."""] ]
          h2 [ _id "add-to-request-list" ] [ locStr s["Add to Request List"] ]
          p [] [
              raw l["Without this box checked, the text of the announcement will only be e-mailed to your group members."]; space
              raw l["If you check this box, however, the text of the announcement will be added to your prayer list under the section you have selected."] ] ]
    
    /// Maintain Group Members
    let members () =
        let s   = I18N.localizer.Force()
        let l   = I18N.forView "Help/SmallGroup/Members"
        use sw  = new StringWriter()
        let raw = rawLocText sw
        [ p [] [ raw l["From this page, you can add, edit, and delete the e-mail addresses for your group."] ]
          h2 [ _id "add-a-new-group-member" ] [ locStr s["Add a New Group Member"] ]
          p [] [
              raw l["To add an e-mail address, click the icon or text in the center of the page, below the title and above the list of addresses for your group."] ]
          h2 [ _id "edit-group-member" ] [ locStr s["Edit Group Member"] ]
          p [] [
              raw l["To edit an e-mail address, click the pencil icon; it's the first icon under the “Actions” column heading."]; space
              raw l["This will allow you to update the name and/or the e-mail address for that member."] ]
          h2 [ _id "delete-a-group-member" ] [ locStr s["Delete a Group Member"] ]
          p [] [
              raw l["To delete an e-mail address, click the trash can icon in the “Actions” column."]; space
              raw l["Note that once an e-mail address has been deleted, it is gone."]; space
              raw l["(Of course, if you delete it in error, you can enter it again using the “Add” instructions above.)"] ] ]
    
    /// Change Preferences
    let preferences () =
        let s   = I18N.localizer.Force()
        let l   = I18N.forView "Help/SmallGroup/Preferences"
        use sw  = new StringWriter()
        let raw = rawLocText sw
        [ p [] [
              raw l["This page allows you to change how your prayer request list looks and behaves."]; space
              raw l["Each section is addressed below."] ]
          h2 [ _id "requests-expire-after" ] [ locStr s["Requests Expire After"] ]
          p [] [
              raw l["When a regular request goes this many days without being updated, it expires and no longer appears on the request list."]; space
              raw l["Note that the categories “Long-Term Requests” and “Expecting” never expire automatically."] ]
          h2 [ _id "requests-new-for" ] [ locStr s["Requests “New” For"] ]
          p [] [
              raw l["Requests that have been updated within this many days are identified by a hollow circle for their bullet, as opposed to a filled circle for other requests."]; space
              raw l["All categories respect this setting."]; space
              raw l["If you do a typo correction on a request, if you do not check the box to update the date, this setting will change the bullet."]; space
              raw l["(NOTE: In the plain-text e-mail, new requests are bulleted with a “+” symbol, and old are bulleted with a “-” symbol.)"] ]
          h2 [ _id "long-term-requests-alerted-for-update" ] [ locStr s["Long-Term Requests Alerted for Update"] ]
          p [] [
              raw l["Requests that have not been updated in this many weeks are identified by an italic font on the “Maintain Requests” page, to remind you to seek updates on these requests so that your prayers can stay relevant and current."] ]
          h2 [ _id "request-sorting" ] [ locStr s["Request Sorting"] ]
          p [] [
              raw l["By default, requests are sorted within each group by the last updated date, with the most recent on top."]; space
              raw l["If you would prefer to have the list sorted by requestor or subject rather than by date, select “Sort by Requestor Name” instead."] ]
          h2 [ _id "e-mail-from-name-and-address" ] [ locStr s["E-mail “From” Name and Address"] ]
          p [] [
              raw l["PrayerTracker must put an name and e-mail address in the “from” position of each e-mail it sends."]; space
              raw l["The default name is “PrayerTracker”, and the default e-mail address is “prayer@bitbadger.solutions”."]; space
              raw l["This will work, but any bounced e-mails and out-of-office replies will be sent to that address (which is not even a real address)."]; space
              raw l["Changing at least the e-mail address to your address will ensure that you receive these e-mails, and can prune your e-mail list accordingly."] ]
          h2 [ _id "e-mail-format" ] [ locStr s["E-mail Format"] ]
          p [] [
              raw l["This is the default e-mail format for your group."]; space
              raw l["The PrayerTracker default is HTML, which sends the list just as you see it online."]; space
              raw l["However, some e-mail clients may not display this properly, so you can choose to default the email to a plain-text format, which does not have colors, italics, or other formatting."]; space
              raw l["The setting on this page is the group default; you can select a format for each recipient on the “Maintain Group Members” page."] ]
          h2 [ _id "colors" ] [ locStr s["Colors"] ]
          p [] [
              raw l["You can customize the colors that are used for the headings and lines in your request list."]; space
              raw l["You can select one of the 16 named colors in the drop down lists, or you can “mix your own” using red, green, and blue (RGB) values between 0 and 255."]; space
              raw l["There is a link on the bottom of the page to a color list with more names and their RGB values, if you're really feeling artistic."]; space
              raw l["The background color cannot be changed."] ]
          h2 [ _id "fonts-for-list" ] [ locStr s["Fonts for List"] ]
          p [] [ raw l["There are two options for fonts that will be used in the prayer request list."] ]
          ul [] [
              li [] [
                  raw l["“Native Fonts” uses a list of fonts that will render the prayer requests in the best available font for their device, whether that is a desktop or laptop computer, mobile device, or tablet."]; space
                  raw l["(This is the default for new small groups.)"] ]
              li [] [
                  raw l["“Named Fonts” uses a comma-separated list of fonts that you specify."]; space
                  raw l["A warning is good here; just because you have an obscure font and like the way that it looks does not mean that others have that same font."]; space
                  raw l["It is generally best to stick with the fonts that come with Windows - fonts like “Arial”, “Times New Roman”, “Tahoma”, and “Comic Sans MS”."]; space
                  raw l["You should also end the font list with either “serif” or “sans-serif”, which will use the browser's default serif (like “Times New Roman”) or sans-serif (like “Arial”) font."] ] ]
          h2 [ _id "heading-list-text-size" ] [ locStr s["Heading / List Text Size"] ]
          p [] [
              raw l["This is the point size to use for each."]; space
              raw l["The default for the heading is 16pt, and the default for the text is 12pt."] ]
          h2 [ _id "making-a-large-print-list" ] [ locStr s["Making a “Large Print” List"] ]
          p [] [
              raw l["If your group is comprised mostly of people who prefer large print, the following settings will make your list look like the typical large-print publication:"] ]
          blockquote [] [
              p [] [ strong [] [ locStr s["Fonts"] ]; br []; raw l["""Named Fonts: "Times New Roman",serif"""] ]
              p [] [ strong [] [ locStr s["Heading Text Size"] ]; br []; rawText "18pt" ]
              p [] [ strong [] [ locStr s["List Text Size"] ]; br []; rawText "16pt" ] ]
          h2 [ _id "request-list-visibility" ] [ locStr s["Request List Visibility"] ]
          p [] [
              raw l["The group's request list can be either public, private, or password-protected."]; space
              raw l["Public lists are available without logging in, and private lists are only available online to administrators (though the list can still be sent via e-mail by an administrator)."]; space
              raw l["Password-protected lists allow group members to log in and view the current request list online, using the “Group Log On” link and providing this password."]; space
              raw l["As this is a shared password, it is stored in plain text, so you can easily see what it is."]; space
              raw l["If you select “Password Protected” but do not enter a password, the list remains private, which is also the default value."]; space
              raw l["(Changing this password will force all members of the group who logged in with the “Remember Me” box checked to provide the new password.)"] ]
          h2 [ _id "time-zone" ] [ locStr s["Time Zone"] ]
          p [] [
              raw l["This is the time zone that you would like to use for your group."]; space
              raw l["""If you do not see your time zone listed, just <a href="mailto:daniel@bitbadger.solutions?subject=PrayerTracker+Time+Zone">contact Daniel</a> and tell him what time zone you need."""] ]
          h2 [ _id "page-size" ] [ locStr s["Page Size"] ]
          p [] [
              raw l["As small groups use PrayerTracker, they accumulate many expired requests."]; space
              raw l["When lists of requests include expired requests, the results will be broken up into pages."]; space
              raw l["The default value is 100 requests per page, but may be set as low as 10 or as high as 255."] ]
          h2 [ _id "as-of-date-display" ] [ locStr s["“As of” Date Display"] ]
          p [] [
              raw l["PrayerTracker can display the last date a request was updated, at the end of the request text."]; space
              raw l["By default, it does not."]; space
              raw l["If you select a short date, it will show “(as of 10/11/2015)” (for October 11, 2015); if you select a long date, it will show “(as of Sunday, October 11, 2015)”."] ] ]

/// Help for user pages
module User =
    
    /// Log On
    let logOn () =
        let s   = I18N.localizer.Force()
        let l   = I18N.forView "Help/User/LogOn"
        use sw  = new StringWriter()
        let raw = rawLocText sw
        [ p [] [
              raw l["This page allows you to log on to PrayerTracker."]; space
              raw l["There are two different levels of access for PrayerTracker - user and group."] ]
          h2 [ _id "user-log-on" ] [ locStr s["User Log On"] ]
          p [] [
              raw l["Enter your e-mail address and password into the appropriate boxes, then select your group."]; space
              raw l["If you want PrayerTracker to remember you on your computer, click the “Remember Me” box before clicking the “Log On” button."] ]
          h2 [ _id "group-log-on" ] [ locStr s["Group Log On"] ]
          p [] [
              raw l["If your group has defined a password to use to allow you to view their request list online, select your group from the drop down list, then enter the group password into the appropriate box."]; space
              raw l["If you want PrayerTracker to remember your group, click the “Remember Me” box before clicking the “Log On” button."] ] ]
    
    /// Change Your Password
    let password () =
        let s   = I18N.localizer.Force()
        let l   = I18N.forView "Help/User/Password"
        use sw  = new StringWriter()
        let raw = rawLocText sw
        [ p [] [
              raw l["This page will let you change your password."]; space
              raw l["Enter your existing password in the top box, then enter your new password in the bottom two boxes."]; space
              raw l["Entering your existing password is a security measure; with the “Remember Me” box on the log in page, this will prevent someone else who may be using your computer from being able to simply go to the site and change your password."] ]
          p [] [
              raw l["If you cannot remember your existing password, we cannot retrieve it, but we can set it to something known so that you can then change it to your password."]; space
              a [ _href $"""mailto:daniel@bitbadger.solutions?subject={l["PrayerTracker+Password+Help"].Value}""" ] [
                  raw l["Click here to request help resetting your password."] ] ] ]
